{% extends "elegant/error_base.html" %}
{% load i18n %}

{% block title %}{% trans 'Page not found' %}{% endblock %}

{% block error %}{% trans 'error'|capfirst %} 404{% endblock %}

{% block content %}
  {% trans "We're sorry, but the requested page could not be found." %}
{% endblock %}
