{% load i18n %}
{% load elegant_shortcuts %}

{% if enable_admin_shortcuts %}
  {% if admin_shortcuts %}
    <ul class="shortcuts" id="shortcuts">
      {% for group in admin_shortcuts %}
        {% if group.title %}<h2>{{ group.title }}</h2>{% endif %}
        <ul>
          {% for shortcut in group.shortcuts %}
            <li>{% include 'shortcuts/shortcut.html' %}</li>
          {% endfor %}
        </ul>
      {% endfor %}
    </ul>
  {% endif %}

  {% if enable_hide_app_list %}
    <a href="#" id="toggle_app_list"><span class="open">&uarr;&uarr;&uarr;</span><span
      class="closed">&darr;&darr;&darr;</span>&nbsp;&nbsp;{% trans 'Advanced' %}&nbsp;&nbsp;</a>
  {% endif %}

{% endif %}
