# flake8: noqa
from .mixins.objects import action
from .mixins.objects import BaseDjangoObjectActions
from .mixins.objects import DjangoObjectActions
from .mixins.objects import takes_instance_or_queryset

__version__ = '0.2.6'
VERSION = __version__
