.date_range_filter .add-on, .date_range_filter .datetimeshortcuts a {
    margin-top: 5px;
}

.date_range_filter .datetimeshortcuts a:first-child {
    display: none;
}

.date_range_filter label {
    position: relative;
    top: 4px;
    margin-right: 7px;
}

.date_range_filter, .elegant-date {
    display: inline-block;
}

.date_range_filter .elegant-date {
    width: 130px;
}



p.date {
  margin:0;
}
