.filebrowser .inner-two-columns .inner-center-column {
    margin-right: 280px;
}

.filebrowser .inner-two-columns .inner-right-column {
    width: 260px;
}

.filebrowser .thumbHeader {
    width: 48px;
}

.filebrowser table.clipboard {
    border: 0 !important;
    width: 260px !important;
    margin-right: 20px;
    border-collapse: collapse;
}

.filebrowser table.clipboard tr.clipboardItem td.thumbnail {
    width: 32px !important;
    padding: 0px;
    border-top: 0;
    border-right: 0;
    border-bottom-color: #eee;
}

.filebrowser table.clipboard tr.clipboardItem td.label,
.filebrowser table.clipboard tr.clipboardItem td.thumbnail {
    font-size: 11px;
    overflow: hidden;
    color: #333;
    display: table-cell;
    border-radius: 0;
    white-space: normal;
    line-height: normal;
}

.filebrowser table.clipboard tr.clipboardItem td.buttons {
    display: none;
}

.filebrowser table.clipboard tr.clipboardItem td.label {
    max-width: 200px;
}

.filebrowser table.clipboard tr:first-child td.thumbnail {
    border-top: 1px solid #ddd;
}

.filebrowser table.clipboard tr.noItemsRow td,
.filebrowser table.clipboard tfoot tr td,
.filebrowser table.clipboard td.label {
    border-right: 1px solid #ddd;
}

.filebrowser table.clipboard tfoot tr td {
    border-bottom: 1px solid #d5d5d5;
    padding: 6px 8px;
    background-color: #e5e5e5;
    background-repeat: no-repeat;
    background-image: -webkit-gradient(linear, left top, left bottom, from(#f3f3f3), to(#e5e5e5));
    background-image: -webkit-linear-gradient(#f3f3f3, #e5e5e5);
    background-image: -moz-linear-gradient(#f3f3f3, #e5e5e5);
    background-image: -o-linear-gradient(top, #f3f3f3, #e5e5e5);
    background-image: -khtml-gradient(linear, left top, left bottom, from(#f3f3f3), to(#e5e5e5));
    filter: progid:DXImageTransform.Microsoft.Gradient(StartColorStr='#f3f3f3', EndColorStr='#e5e5e5', GradientType=0);
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#f3f3f3', EndColorStr='#e5e5e5', GradientType=0))";
}

.filebrowser table.clipboard tfoot tr td form {
    margin: 0;
}

.filebrowser table.clipboard .loadingThumb {
    width: 32px;
    height: 32px;
    background-position: center center;
    background-image: url(../img/ajax-loader.gif);
    background-repeat: no-repeat;
}

.filebrowser table.clipboard .fileUploadQueueItem .fileUploadProgress .fileUploadProgressBar {
    background-color: #2F96B4;
    width: 50px;
    height: 4px !important;
    border-radius: 2px;
}

.filebrowser .clipboard-header {
    margin-top: 47px;
}

.filebrowser .clipboard-root {
    margin-top: 20px;
}

.filebrowser .toolbar-content label.checkbox {
    color: #666;
    font-size: 11px;
    margin-left: 5px;
}

.filebrowser .toolbar-content label.checkbox input[type="checkbox"] {
    margin-right: 8px;
}

.filebrowser .folder_header img {
    display: inline-block;
    max-width: 32px;
    margin: -5px 5px 0;
    vertical-align: middle;
}

.filebrowser .folder_header span:last-child a {
    margin-right: 5px;
    font-size: 14px;
    font-weight: normal;
    text-decoration: none;
}

.filebrowser .folder_header span:last-child a:hover {
    text-decoration: underline;
}

.filebrowser .tiny {
    font-size: 11px;
}

.filebrowser .small {
    font-size: 12px;
    font-weight: normal;
}

.filebrowser .file-size {
    color: #666;
}

.filebrowser .file-info {
    line-height: normal;
    font-size: 11px;
}

.filebrowser .this-page {
    display: inline-block;
    margin: 0 10px;
}

.filebrowser .this-page:first-child {
    margin-left: 0;
}

.filebrowser a.insertlinkButton {
    background-image: none;
    padding: 2px 10px;
    width: inherit;
}

/* Siderbar */
#navcontainer {
    text-align: center;
}

#image_container {
    position: relative;
    margin-bottom: 5px;
    color: #666;
}

.filebrowser #changelist {
    padding-top: 5px;
}
