{% load static %}
<a href="#" data-jq-dropdown="#jq-dropdown-{{ dom_id }}">{{ label }}&nbsp;<span class="jq-dropdown-caret"></span></a>
<div id="jq-dropdown-{{ dom_id }}" class="jq-dropdown jq-dropdown-tip jq-dropdown-relative">
  <ul class="jq-dropdown-menu">
    {% for item in items %}
      {% if item.divided %}
        <li class="jq-dropdown-divider"></li>
      {% endif %}
      <li>
        {% if item.enabled %}
          {% if item.method == 'POST' %}
            <form method="post" action="{{ item.url }}">
              {% csrf_token %}
              <input class="{{ item.classes }}" type="submit" title="{{ item.tooltip }}" value="{{ item.label }}"/>
            </form>
          {% else %}
            <a class="{{ item.classes }}" href="{{ item.url }}" title="{{ item.tooltip }}">
              <i class="{% if item.icon %}{{ item.icon }}{% else %}icon-wrench icon-alpha75{% endif %}"></i>
              {{ item.label }}
            </a>
          {% endif %}
        {% else %}
          <span class="{{ item.classes }} jq-disabled" title="{{ item.tooltip }}">{{ item.label }}</span>
        {% endif %}
      </li>
    {% endfor %}
  </ul>
</div>
