.submit-row a.cancel-link {
  width: fit-content;
  /*background: #ba2121;*/
  border-radius: 4px;
  padding: 7px 15px;
  /*line-height: 15px;*/
  /*display: block;*/
  /*height: 15px;*/
  /*color: #fff;*/
}

/*.submit-row a.cancel-link:focus,*/
/*.submit-row a.cancel-link:hover,*/
/*.submit-row a.cancel-link:active {*/
/*  background: #a41515;*/
/*  width: fit-content;*/
/*}*/

.changed-data table {
  width: 100%;
}

.changed-data th,
.changed-data td {
  width: 30%;
  white-space: nowrap;
}

.hidden {
  display: none;
}
